/******************************************************************************
* Copyright (C) 2019 - 2020 Xilinx, Inc.  All rights reserved.
* SPDX-License-Identifier: MIT
******************************************************************************/


/*****************************************************************************/
/**
* @file xaie_events_aieml.h
* @{
*
* Header file containing all events macros for AIEML.
*
* <pre>
* MODIFICATION HISTORY:
*
* Ver   Who      Date     Changes
* ----- ------   -------- -----------------------------------------------------
* 1.0   Dishita  11/21/2019  Initial creation
* 1.1   Nishad   06/02/2020  Move event files under events directory
* 1.2   Nishad   06/02/2020  Rename file attribute to xaie_events_aieml.h
* 1.3   Nishad   06/03/2020  Rename XAIEMLGBL_<MODULE>_EVENT_* macros to
*			     XAIEML_EVENTS_<MODULE>_*
* 1.4   Nishad   06/09/2020  Fix typo in *_MEMORY_* macro
* </pre>
*
******************************************************************************/

/*
 * Macro of all the Events of AIEML for all modules: Core, Memory of AIE tile
 * MEM tile and PL tile
 */

/*Declaration of events for core module of aie tile */
#define XAIEML_EVENTS_CORE_NONE						0
#define XAIEML_EVENTS_CORE_TRUE						1
#define XAIEML_EVENTS_CORE_GROUP_0					2
#define XAIEML_EVENTS_CORE_TIMER_SYNC					3
#define XAIEML_EVENTS_CORE_TIMER_VALUE_REACHED				4
#define XAIEML_EVENTS_CORE_PERF_CNT_0					5
#define XAIEML_EVENTS_CORE_PERF_CNT_1					6
#define XAIEML_EVENTS_CORE_PERF_CNT_2					7
#define XAIEML_EVENTS_CORE_PERF_CNT_3					8
#define XAIEML_EVENTS_CORE_COMBO_EVENT_0					9
#define XAIEML_EVENTS_CORE_COMBO_EVENT_1					10
#define XAIEML_EVENTS_CORE_COMBO_EVENT_2					11
#define XAIEML_EVENTS_CORE_COMBO_EVENT_3					12
#define XAIEML_EVENTS_CORE_EDGE_DETECTION_EVENT_0			13
#define XAIEML_EVENTS_CORE_EDGE_DETECTION_EVENT_1			14
#define XAIEML_EVENTS_CORE_GROUP_PC_EVENT				15
#define XAIEML_EVENTS_CORE_PC_0						16
#define XAIEML_EVENTS_CORE_PC_1						17
#define XAIEML_EVENTS_CORE_PC_2						18
#define XAIEML_EVENTS_CORE_PC_3						19
#define XAIEML_EVENTS_CORE_PC_RANGE_0_1					20
#define XAIEML_EVENTS_CORE_PC_RANGE_2_3					21
#define XAIEML_EVENTS_CORE_GROUP_STALL					22
#define XAIEML_EVENTS_CORE_MEMORY_STALL					23
#define XAIEML_EVENTS_CORE_STREAM_STALL					24
#define XAIEML_EVENTS_CORE_CASCADE_STALL					25
#define XAIEML_EVENTS_CORE_LOCK_STALL					26
#define XAIEML_EVENTS_CORE_DEBUG_HALTED					27
#define XAIEML_EVENTS_CORE_ACTIVE					28
#define XAIEML_EVENTS_CORE_DISABLED					29
#define XAIEML_EVENTS_CORE_ECC_ERROR_STALL				30
#define XAIEML_EVENTS_CORE_ECC_SCRUBBING_STALL				31
#define XAIEML_EVENTS_CORE_GROUP_PROGRAM_FLOW				32
#define XAIEML_EVENTS_CORE_INSTR_EVENT_0					33
#define XAIEML_EVENTS_CORE_INSTR_EVENT_1					34
#define XAIEML_EVENTS_CORE_INSTR_CALL					35
#define XAIEML_EVENTS_CORE_INSTR_RETURN					36
#define XAIEML_EVENTS_CORE_INSTR_VECTOR					37
#define XAIEML_EVENTS_CORE_INSTR_LOAD					38
#define XAIEML_EVENTS_CORE_INSTR_STORE					39
#define XAIEML_EVENTS_CORE_INSTR_STREAM_GET				40
#define XAIEML_EVENTS_CORE_INSTR_STREAM_PUT				41
#define XAIEML_EVENTS_CORE_INSTR_CASCADE_GET				42
#define XAIEML_EVENTS_CORE_INSTR_CASCADE_PUT				43
#define XAIEML_EVENTS_CORE_INSTR_LOCK_ACQUIRE_REQ			44
#define XAIEML_EVENTS_CORE_INSTR_LOCK_RELEASE_REQ			45
#define XAIEML_EVENTS_CORE_GROUP_ERRORS_0				46
#define XAIEML_EVENTS_CORE_GROUP_ERRORS_1				47
#define XAIEML_EVENTS_CORE_SRS_OVERFLOW					48
#define XAIEML_EVENTS_CORE_UPS_OVERFLOW					49
#define XAIEML_EVENTS_CORE_FP_HUGE					50
#define XAIEML_EVENTS_CORE_INT_FP_0					51
#define XAIEML_EVENTS_CORE_FP_INVALID					52
#define XAIEML_EVENTS_CORE_FP_INF					53
#define XAIEML_EVENTS_CORE_PM_REG_ACCESS_FAILURE				55
#define XAIEML_EVENTS_CORE_STREAM_PKT_PARITY_ERROR			56
#define XAIEML_EVENTS_CORE_CONTROL_PKT_ERROR				57
#define XAIEML_EVENTS_CORE_AXI_MM_SLAVE_ERROR				58
#define XAIEML_EVENTS_CORE_INSTR_DECOMPRSN_ERROR				59
#define XAIEML_EVENTS_CORE_DM_ADDRESS_OUT_OF_RANGE			60
#define XAIEML_EVENTS_CORE_PM_ECC_ERROR_SCRUB_CORRECTED			61
#define XAIEML_EVENTS_CORE_PM_ECC_ERROR_SCRUB_2BIT			62
#define XAIEML_EVENTS_CORE_PM_ECC_ERROR_1BIT				63
#define XAIEML_EVENTS_CORE_PM_ECC_ERROR_2BIT				64
#define XAIEML_EVENTS_CORE_PM_ADDRESS_OUT_OF_RANGE			65
#define XAIEML_EVENTS_CORE_DM_ACCESS_TO_UNAVAILABLE			66
#define XAIEML_EVENTS_CORE_LOCK_ACCESS_TO_UNAVAILABLE			67
#define XAIEML_EVENTS_CORE_INSTR_WARNING					68
#define XAIEML_EVENTS_CORE_INSTR_ERROR					69
#define XAIEML_EVENTS_CORE_DECOMPRESSION_UNDERFLOW			70
#define XAIEML_EVENTS_CORE_STREAM_SWITCH_PORT_PARITY_ERROR		71
#define XAIEML_EVENTS_CORE_PROCESSOR_BUS_ERROR				72
#define XAIEML_EVENTS_CORE_GROUP_STREAM_SWITCH				73
#define XAIEML_EVENTS_CORE_PORT_IDLE_0					74
#define XAIEML_EVENTS_CORE_PORT_RUNNING_0				75
#define XAIEML_EVENTS_CORE_PORT_STALLED_0				76
#define XAIEML_EVENTS_CORE_PORT_TLAST_0					77
#define XAIEML_EVENTS_CORE_PORT_IDLE_1					78
#define XAIEML_EVENTS_CORE_PORT_RUNNING_1				79
#define XAIEML_EVENTS_CORE_PORT_STALLED_1				80
#define XAIEML_EVENTS_CORE_PORT_TLAST_1					81
#define XAIEML_EVENTS_CORE_PORT_IDLE_2					82
#define XAIEML_EVENTS_CORE_PORT_RUNNING_2				83
#define XAIEML_EVENTS_CORE_PORT_STALLED_2				84
#define XAIEML_EVENTS_CORE_PORT_TLAST_2					85
#define XAIEML_EVENTS_CORE_PORT_IDLE_3					86
#define XAIEML_EVENTS_CORE_PORT_RUNNING_3				87
#define XAIEML_EVENTS_CORE_PORT_STALLED_3				88
#define XAIEML_EVENTS_CORE_PORT_TLAST_3					89
#define XAIEML_EVENTS_CORE_PORT_IDLE_4					90
#define XAIEML_EVENTS_CORE_PORT_RUNNING_4				91
#define XAIEML_EVENTS_CORE_PORT_STALLED_4				92
#define XAIEML_EVENTS_CORE_PORT_TLAST_4					93
#define XAIEML_EVENTS_CORE_PORT_IDLE_5					94
#define XAIEML_EVENTS_CORE_PORT_RUNNING_5				95
#define XAIEML_EVENTS_CORE_PORT_STALLED_5				96
#define XAIEML_EVENTS_CORE_PORT_TLAST_5					97
#define XAIEML_EVENTS_CORE_PORT_IDLE_6					98
#define XAIEML_EVENTS_CORE_PORT_RUNNING_6				99
#define XAIEML_EVENTS_CORE_PORT_STALLED_6				100
#define XAIEML_EVENTS_CORE_PORT_TLAST_6					101
#define XAIEML_EVENTS_CORE_PORT_IDLE_7					102
#define XAIEML_EVENTS_CORE_PORT_RUNNING_7				103
#define XAIEML_EVENTS_CORE_PORT_STALLED_7				104
#define XAIEML_EVENTS_CORE_PORT_TLAST_7					105
#define XAIEML_EVENTS_CORE_GROUP_BROADCAST				106
#define XAIEML_EVENTS_CORE_BROADCAST_0					107
#define XAIEML_EVENTS_CORE_BROADCAST_1					108
#define XAIEML_EVENTS_CORE_BROADCAST_2					109
#define XAIEML_EVENTS_CORE_BROADCAST_3					110
#define XAIEML_EVENTS_CORE_BROADCAST_4					111
#define XAIEML_EVENTS_CORE_BROADCAST_5					112
#define XAIEML_EVENTS_CORE_BROADCAST_6					113
#define XAIEML_EVENTS_CORE_BROADCAST_7					114
#define XAIEML_EVENTS_CORE_BROADCAST_8					115
#define XAIEML_EVENTS_CORE_BROADCAST_9					116
#define XAIEML_EVENTS_CORE_BROADCAST_10					117
#define XAIEML_EVENTS_CORE_BROADCAST_11					118
#define XAIEML_EVENTS_CORE_BROADCAST_12					119
#define XAIEML_EVENTS_CORE_BROADCAST_13					120
#define XAIEML_EVENTS_CORE_BROADCAST_14					121
#define XAIEML_EVENTS_CORE_BROADCAST_15					122
#define XAIEML_EVENTS_CORE_GROUP_USER_EVENT				123
#define XAIEML_EVENTS_CORE_USER_EVENT_0					124
#define XAIEML_EVENTS_CORE_USER_EVENT_1					125
#define XAIEML_EVENTS_CORE_USER_EVENT_2					126
#define XAIEML_EVENTS_CORE_USER_EVENT_3					127

/*Declaration of events for mem module of aie tile */
#define XAIEML_EVENTS_MEM_NONE						0
#define XAIEML_EVENTS_MEM_TRUE						1
#define XAIEML_EVENTS_MEM_GROUP_0					2
#define XAIEML_EVENTS_MEM_TIMER_SYNC					3
#define XAIEML_EVENTS_MEM_TIMER_VALUE_REACHED				4
#define XAIEML_EVENTS_MEM_PERF_CNT_0					5
#define XAIEML_EVENTS_MEM_PERF_CNT_1					6
#define XAIEML_EVENTS_MEM_COMBO_EVENT_0					7
#define XAIEML_EVENTS_MEM_COMBO_EVENT_1					8
#define XAIEML_EVENTS_MEM_COMBO_EVENT_2					9
#define XAIEML_EVENTS_MEM_COMBO_EVENT_3					10
#define XAIEML_EVENTS_MEM_EDGE_DETECTION_EVENT_0				11
#define XAIEML_EVENTS_MEM_EDGE_DETECTION_EVENT_1				12
#define XAIEML_EVENTS_MEM_GROUP_WATCHPOINT				15
#define XAIEML_EVENTS_MEM_WATCHPOINT_0					16
#define XAIEML_EVENTS_MEM_WATCHPOINT_1					17
#define XAIEML_EVENTS_MEM_GROUP_DMA_ACTIVITY				18
#define XAIEML_EVENTS_MEM_DMA_S2MM_0_START_TASK				19
#define XAIEML_EVENTS_MEM_DMA_S2MM_1_START_TASK				20
#define XAIEML_EVENTS_MEM_DMA_MM2S_0_START_TASK				21
#define XAIEML_EVENTS_MEM_DMA_MM2S_1_START_TASK				22
#define XAIEML_EVENTS_MEM_DMA_S2MM_0_FINISHED_BD				23
#define XAIEML_EVENTS_MEM_DMA_S2MM_1_FINISHED_BD				24
#define XAIEML_EVENTS_MEM_DMA_MM2S_0_FINISHED_BD				25
#define XAIEML_EVENTS_MEM_DMA_MM2S_1_FINISHED_BD				26
#define XAIEML_EVENTS_MEM_DMA_S2MM_0_FINISHED_TASK			27
#define XAIEML_EVENTS_MEM_DMA_S2MM_1_FINISHED_TASK			28
#define XAIEML_EVENTS_MEM_DMA_MM2S_0_FINISHED_TASK			29
#define XAIEML_EVENTS_MEM_DMA_MM2S_1_FINISHED_TASK			30
#define XAIEML_EVENTS_MEM_DMA_S2MM_0_STALLED_LOCK			31
#define XAIEML_EVENTS_MEM_DMA_S2MM_1_STALLED_LOCK			32
#define XAIEML_EVENTS_MEM_DMA_MM2S_0_STALLED_LOCK			33
#define XAIEML_EVENTS_MEM_DMA_MM2S_1_STALLED_LOCK			34
#define XAIEML_EVENTS_MEM_DMA_S2MM_0_STREAM_STARVATION			35
#define XAIEML_EVENTS_MEM_DMA_S2MM_1_STREAM_STARVATION			36
#define XAIEML_EVENTS_MEM_DMA_MM2S_0_STREAM_BACKPRESSURE			37
#define XAIEML_EVENTS_MEM_DMA_MM2S_1_STREAM_BACKPRESSURE			38
#define XAIEML_EVENTS_MEM_DMA_S2MM_0_MEMORY_BACKPRESSURE			39
#define XAIEML_EVENTS_MEM_DMA_S2MM_1_MEMORY_BACKPRESSURE			40
#define XAIEML_EVENTS_MEM_DMA_MM2S_0_MEMORY_STARVATION			41
#define XAIEML_EVENTS_MEM_DMA_MM2S_1_MEMORY_STARVATION			42
#define XAIEML_EVENTS_MEM_GROUP_LOCK					43
#define XAIEML_EVENTS_MEM_LOCK_SEL0_ACQ_EQ				44
#define XAIEML_EVENTS_MEM_LOCK_SEL0_ACQ_GE				45
#define XAIEML_EVENTS_MEM_LOCK_0_REL					46
#define XAIEML_EVENTS_MEM_LOCK_SEL0_EQUAL_TO_VALUE			47
#define XAIEML_EVENTS_MEM_LOCK_SEL1_ACQ_EQ				48
#define XAIEML_EVENTS_MEM_LOCK_SEL1_ACQ_GE				49
#define XAIEML_EVENTS_MEM_LOCK_1_REL					50
#define XAIEML_EVENTS_MEM_LOCK_SEL1_EQUAL_TO_VALUE			51
#define XAIEML_EVENTS_MEM_LOCK_SEL2_ACQ_EQ				52
#define XAIEML_EVENTS_MEM_LOCK_SEL2_ACQ_GE				53
#define XAIEML_EVENTS_MEM_LOCK_2_REL					54
#define XAIEML_EVENTS_MEM_LOCK_SEL2_EQUAL_TO_VALUE			55
#define XAIEML_EVENTS_MEM_LOCK_SEL3_ACQ_EQ				56
#define XAIEML_EVENTS_MEM_LOCK_SEL3_ACQ_GE				57
#define XAIEML_EVENTS_MEM_LOCK_3_REL					58
#define XAIEML_EVENTS_MEM_LOCK_SEL3_EQUAL_TO_VALUE			59
#define XAIEML_EVENTS_MEM_LOCK_SEL4_ACQ_EQ				60
#define XAIEML_EVENTS_MEM_LOCK_SEL4_ACQ_GE				61
#define XAIEML_EVENTS_MEM_LOCK_4_REL					62
#define XAIEML_EVENTS_MEM_LOCK_SEL4_EQUAL_TO_VALUE			63
#define XAIEML_EVENTS_MEM_LOCK_SEL5_ACQ_EQ				64
#define XAIEML_EVENTS_MEM_LOCK_SEL5_ACQ_GE				65
#define XAIEML_EVENTS_MEM_LOCK_5_REL					66
#define XAIEML_EVENTS_MEM_LOCK_SEL5_EQUAL_TO_VALUE			67
#define XAIEML_EVENTS_MEM_LOCK_SEL6_ACQ_EQ				68
#define XAIEML_EVENTS_MEM_LOCK_SEL6_ACQ_GE				69
#define XAIEML_EVENTS_MEM_LOCK_6_REL					70
#define XAIEML_EVENTS_MEM_LOCK_SEL6_EQUAL_TO_VALUE			71
#define XAIEML_EVENTS_MEM_LOCK_SEL7_ACQ_EQ				72
#define XAIEML_EVENTS_MEM_LOCK_SEL7_ACQ_GE				73
#define XAIEML_EVENTS_MEM_LOCK_7_REL					74
#define XAIEML_EVENTS_MEM_LOCK_SEL7_EQUAL_TO_VALUE			75
#define XAIEML_EVENTS_MEM_GROUP_MEMORY_CONFLICT				76
#define XAIEML_EVENTS_MEM_CONFLICT_DM_BANK_0				77
#define XAIEML_EVENTS_MEM_CONFLICT_DM_BANK_1				78
#define XAIEML_EVENTS_MEM_CONFLICT_DM_BANK_2				79
#define XAIEML_EVENTS_MEM_CONFLICT_DM_BANK_3				80
#define XAIEML_EVENTS_MEM_CONFLICT_DM_BANK_4				81
#define XAIEML_EVENTS_MEM_CONFLICT_DM_BANK_5				82
#define XAIEML_EVENTS_MEM_CONFLICT_DM_BANK_6				83
#define XAIEML_EVENTS_MEM_CONFLICT_DM_BANK_7				84
#define XAIEML_EVENTS_MEM_GROUP_ERRORS					86
#define XAIEML_EVENTS_MEM_DM_ECC_ERROR_SCRUB_CORRECTED			87
#define XAIEML_EVENTS_MEM_DM_ECC_ERROR_SCRUB_2BIT			88
#define XAIEML_EVENTS_MEM_DM_ECC_ERROR_1BIT				89
#define XAIEML_EVENTS_MEM_DM_ECC_ERROR_2BIT				90
#define XAIEML_EVENTS_MEM_DM_PARITY_ERROR_BANK_2				91
#define XAIEML_EVENTS_MEM_DM_PARITY_ERROR_BANK_3				92
#define XAIEML_EVENTS_MEM_DM_PARITY_ERROR_BANK_4				93
#define XAIEML_EVENTS_MEM_DM_PARITY_ERROR_BANK_5				94
#define XAIEML_EVENTS_MEM_DM_PARITY_ERROR_BANK_6				95
#define XAIEML_EVENTS_MEM_DM_PARITY_ERROR_BANK_7				96
#define XAIEML_EVENTS_MEM_DMA_S2MM_0_ERROR				97
#define XAIEML_EVENTS_MEM_DMA_S2MM_1_ERROR				98
#define XAIEML_EVENTS_MEM_DMA_MM2S_0_ERROR				99
#define XAIEML_EVENTS_MEM_DMA_MM2S_1_ERROR				100
#define XAIEML_EVENTS_MEM_LOCK_ERROR					101
#define XAIEML_EVENTS_MEM_DMA_TASK_TOKEN_STALL				102
#define XAIEML_EVENTS_MEM_GROUP_BROADCAST				106
#define XAIEML_EVENTS_MEM_BROADCAST_0					107
#define XAIEML_EVENTS_MEM_BROADCAST_1					108
#define XAIEML_EVENTS_MEM_BROADCAST_2					109
#define XAIEML_EVENTS_MEM_BROADCAST_3					110
#define XAIEML_EVENTS_MEM_BROADCAST_4					111
#define XAIEML_EVENTS_MEM_BROADCAST_5					112
#define XAIEML_EVENTS_MEM_BROADCAST_6					113
#define XAIEML_EVENTS_MEM_BROADCAST_7					114
#define XAIEML_EVENTS_MEM_BROADCAST_8					115
#define XAIEML_EVENTS_MEM_BROADCAST_9					116
#define XAIEML_EVENTS_MEM_BROADCAST_10					117
#define XAIEML_EVENTS_MEM_BROADCAST_11					118
#define XAIEML_EVENTS_MEM_BROADCAST_12					119
#define XAIEML_EVENTS_MEM_BROADCAST_13					120
#define XAIEML_EVENTS_MEM_BROADCAST_14					121
#define XAIEML_EVENTS_MEM_BROADCAST_15					122
#define XAIEML_EVENTS_MEM_GROUP_USER_EVENT				123
#define XAIEML_EVENTS_MEM_USER_EVENT_0					124
#define XAIEML_EVENTS_MEM_USER_EVENT_1					125
#define XAIEML_EVENTS_MEM_USER_EVENT_2					126
#define XAIEML_EVENTS_MEM_USER_EVENT_3					127

/*Declaration of events for PL/Noc module */
#define XAIEML_EVENTS_PL_NONE						0
#define XAIEML_EVENTS_PL_TRUE						1
#define XAIEML_EVENTS_PL_GROUP_0						2
#define XAIEML_EVENTS_PL_TIMER_SYNC					3
#define XAIEML_EVENTS_PL_TIMER_VALUE_REACHED				4
#define XAIEML_EVENTS_PL_PERF_CNT_0					5
#define XAIEML_EVENTS_PL_PERF_CNT_1					6
#define XAIEML_EVENTS_PL_COMBO_EVENT_0					7
#define XAIEML_EVENTS_PL_COMBO_EVENT_1					8
#define XAIEML_EVENTS_PL_COMBO_EVENT_2					9
#define XAIEML_EVENTS_PL_COMBO_EVENT_3					10
#define XAIEML_EVENTS_PL_EDGE_DETECTION_EVENT_0				11
#define XAIEML_EVENTS_PL_EDGE_DETECTION_EVENT_1				12
#define XAIEML_EVENTS_PL_GROUP_DMA_ACTIVITY				13
#define XAIEML_EVENTS_PL_DMA_S2MM_0_START_TASK				14
#define XAIEML_EVENTS_PL_DMA_S2MM_1_START_TASK				15
#define XAIEML_EVENTS_PL_DMA_MM2S_0_START_TASK				16
#define XAIEML_EVENTS_PL_DMA_MM2S_1_START_TASK				17
#define XAIEML_EVENTS_PL_DMA_S2MM_0_FINISHED_BD				18
#define XAIEML_EVENTS_PL_DMA_S2MM_1_FINISHED_BD				19
#define XAIEML_EVENTS_PL_DMA_MM2S_0_FINISHED_BD				20
#define XAIEML_EVENTS_PL_DMA_MM2S_1_FINISHED_BD				21
#define XAIEML_EVENTS_PL_DMA_S2MM_0_FINISHED_TASK			22
#define XAIEML_EVENTS_PL_DMA_S2MM_1_FINISHED_TASK			23
#define XAIEML_EVENTS_PL_DMA_MM2S_0_FINISHED_TASK			24
#define XAIEML_EVENTS_PL_DMA_MM2S_1_FINISHED_TASK			25
#define XAIEML_EVENTS_PL_DMA_S2MM_0_STALLED_LOCK				26
#define XAIEML_EVENTS_PL_DMA_S2MM_1_STALLED_LOCK				27
#define XAIEML_EVENTS_PL_DMA_MM2S_0_STALLED_LOCK				28
#define XAIEML_EVENTS_PL_DMA_MM2S_1_STALLED_LOCK				29
#define XAIEML_EVENTS_PL_DMA_S2MM_0_STREAM_STARVATION			30
#define XAIEML_EVENTS_PL_DMA_S2MM_1_STREAM_STARVATION			31
#define XAIEML_EVENTS_PL_DMA_MM2S_0_STREAM_BACKPRESSURE			32
#define XAIEML_EVENTS_PL_DMA_MM2S_1_STREAM_BACKPRESSURE			33
#define XAIEML_EVENTS_PL_DMA_S2MM_0_MEMORY_BACKPRESSURE			34
#define XAIEML_EVENTS_PL_DMA_S2MM_1_MEMORY_BACKPRESSURE			35
#define XAIEML_EVENTS_PL_DMA_MM2S_0_MEMORY_STARVATION			36
#define XAIEML_EVENTS_PL_DMA_MM2S_1_MEMORY_STARVATION			37
#define XAIEML_EVENTS_PL_GROUP_LOCK					38
#define XAIEML_EVENTS_PL_LOCK_0_ACQ_EQ					39
#define XAIEML_EVENTS_PL_LOCK_0_ACQ_GE					40
#define XAIEML_EVENTS_PL_LOCK_0_REL					41
#define XAIEML_EVENTS_PL_LOCK_0_EQUAL_TO_VALUE				42
#define XAIEML_EVENTS_PL_LOCK_1_ACQ_EQ					43
#define XAIEML_EVENTS_PL_LOCK_1_ACQ_GE					44
#define XAIEML_EVENTS_PL_LOCK_1_REL					45
#define XAIEML_EVENTS_PL_LOCK_1_EQUAL_TO_VALUE				46
#define XAIEML_EVENTS_PL_LOCK_2_ACQ_EQ					47
#define XAIEML_EVENTS_PL_LOCK_2_ACQ_GE					48
#define XAIEML_EVENTS_PL_LOCK_2_REL					49
#define XAIEML_EVENTS_PL_LOCK_2_EQUAL_TO_VALUE				50
#define XAIEML_EVENTS_PL_LOCK_3_ACQ_EQ					51
#define XAIEML_EVENTS_PL_LOCK_3_ACQ_GE					52
#define XAIEML_EVENTS_PL_LOCK_3_REL					53
#define XAIEML_EVENTS_PL_LOCK_3_EQUAL_TO_VALUE				54
#define XAIEML_EVENTS_PL_LOCK_4_ACQ_EQ					55
#define XAIEML_EVENTS_PL_LOCK_4_ACQ_GE					56
#define XAIEML_EVENTS_PL_LOCK_4_REL					57
#define XAIEML_EVENTS_PL_LOCK_4_EQUAL_TO_VALUE				58
#define XAIEML_EVENTS_PL_LOCK_5_ACQ_EQ					59
#define XAIEML_EVENTS_PL_LOCK_5_ACQ_GE					60
#define XAIEML_EVENTS_PL_LOCK_5_REL					61
#define XAIEML_EVENTS_PL_LOCK_5_EQUAL_TO_VALUE				62
#define XAIEML_EVENTS_PL_GROUP_ERRORS					63
#define XAIEML_EVENTS_PL_AXI_MM_SLAVE_ERROR				64
#define XAIEML_EVENTS_PL_CONTROL_PKT_ERROR				65
#define XAIEML_EVENTS_PL_STREAM_SWITCH_PARITY_ERROR			66
#define XAIEML_EVENTS_PL_AXI_MM_DECODE_NSU_ERROR				67
#define XAIEML_EVENTS_PL_AXI_MM_SLAVE_NSU_ERROR				68
#define XAIEML_EVENTS_PL_AXI_MM_UNSUPPORTED_TRAFFIC			69
#define XAIEML_EVENTS_PL_AXI_MM_UNSECURE_ACCESS_IN_SECURE_MODE		70
#define XAIEML_EVENTS_PL_AXI_MM_BYTE_STROBE_ERROR			71
#define XAIEML_EVENTS_PL_DMA_S2MM_ERROR					72
#define XAIEML_EVENTS_PL_DMA_MM2S_ERROR					73
#define XAIEML_EVENTS_PL_LOCK_ERROR					74
#define XAIEML_EVENTS_PL_DMA_TASK_TOKEN_STALL				75
#define XAIEML_EVENTS_PL_GROUP_STREAM_SWITCH				76
#define XAIEML_EVENTS_PL_PORT_IDLE_0					77
#define XAIEML_EVENTS_PL_PORT_RUNNING_0					78
#define XAIEML_EVENTS_PL_PORT_STALLED_0					79
#define XAIEML_EVENTS_PL_PORT_TLAST_0					80
#define XAIEML_EVENTS_PL_PORT_IDLE_1					81
#define XAIEML_EVENTS_PL_PORT_RUNNING_1					82
#define XAIEML_EVENTS_PL_PORT_STALLED_1					83
#define XAIEML_EVENTS_PL_PORT_TLAST_1					84
#define XAIEML_EVENTS_PL_PORT_IDLE_2					85
#define XAIEML_EVENTS_PL_PORT_RUNNING_2					86
#define XAIEML_EVENTS_PL_PORT_STALLED_2					87
#define XAIEML_EVENTS_PL_PORT_TLAST_2					88
#define XAIEML_EVENTS_PL_PORT_IDLE_3					89
#define XAIEML_EVENTS_PL_PORT_RUNNING_3					90
#define XAIEML_EVENTS_PL_PORT_STALLED_3					91
#define XAIEML_EVENTS_PL_PORT_TLAST_3					92
#define XAIEML_EVENTS_PL_PORT_IDLE_4					93
#define XAIEML_EVENTS_PL_PORT_RUNNING_4					94
#define XAIEML_EVENTS_PL_PORT_STALLED_4					95
#define XAIEML_EVENTS_PL_PORT_TLAST_4					96
#define XAIEML_EVENTS_PL_PORT_IDLE_5					97
#define XAIEML_EVENTS_PL_PORT_RUNNING_5					98
#define XAIEML_EVENTS_PL_PORT_STALLED_5					99
#define XAIEML_EVENTS_PL_PORT_TLAST_5					100
#define XAIEML_EVENTS_PL_PORT_IDLE_6					101
#define XAIEML_EVENTS_PL_PORT_RUNNING_6					102
#define XAIEML_EVENTS_PL_PORT_STALLED_6					103
#define XAIEML_EVENTS_PL_PORT_TLAST_6					104
#define XAIEML_EVENTS_PL_PORT_IDLE_7					105
#define XAIEML_EVENTS_PL_PORT_RUNNING_7					106
#define XAIEML_EVENTS_PL_PORT_STALLED_7					107
#define XAIEML_EVENTS_PL_PORT_TLAST_7					108
#define XAIEML_EVENTS_PL_GROUP_BROADCAST_A				109
#define XAIEML_EVENTS_PL_BROADCAST_A_0					110
#define XAIEML_EVENTS_PL_BROADCAST_A_1					111
#define XAIEML_EVENTS_PL_BROADCAST_A_2					112
#define XAIEML_EVENTS_PL_BROADCAST_A_3					113
#define XAIEML_EVENTS_PL_BROADCAST_A_4					114
#define XAIEML_EVENTS_PL_BROADCAST_A_5					115
#define XAIEML_EVENTS_PL_BROADCAST_A_6					116
#define XAIEML_EVENTS_PL_BROADCAST_A_7					117
#define XAIEML_EVENTS_PL_BROADCAST_A_8					118
#define XAIEML_EVENTS_PL_BROADCAST_A_9					119
#define XAIEML_EVENTS_PL_BROADCAST_A_10					120
#define XAIEML_EVENTS_PL_BROADCAST_A_11					121
#define XAIEML_EVENTS_PL_BROADCAST_A_12					122
#define XAIEML_EVENTS_PL_BROADCAST_A_13					123
#define XAIEML_EVENTS_PL_BROADCAST_A_14					124
#define XAIEML_EVENTS_PL_BROADCAST_A_15					125
#define XAIEML_EVENTS_PL_USER_EVENT_0					126
#define XAIEML_EVENTS_PL_USER_EVENT_1					127

/*Declaration of events for Mem Tile module */
#define XAIEML_EVENTS_MEM_TILE_NONE					0
#define XAIEML_EVENTS_MEM_TILE_TRUE					1
#define XAIEML_EVENTS_MEM_TILE_GROUP_0					2
#define XAIEML_EVENTS_MEM_TILE_TIMER_SYNC				3
#define XAIEML_EVENTS_MEM_TILE_TIMER_VALUE_REACHED			4
#define XAIEML_EVENTS_MEM_TILE_PERF_CNT0_EVENT				5
#define XAIEML_EVENTS_MEM_TILE_PERF_CNT1_EVENT				6
#define XAIEML_EVENTS_MEM_TILE_PERF_CNT2_EVENT				7
#define XAIEML_EVENTS_MEM_TILE_PERF_CNT3_EVENT				8
#define XAIEML_EVENTS_MEM_TILE_COMBO_EVENT_0				9
#define XAIEML_EVENTS_MEM_TILE_COMBO_EVENT_1				10
#define XAIEML_EVENTS_MEM_TILE_COMBO_EVENT_2				11
#define XAIEML_EVENTS_MEM_TILE_COMBO_EVENT_3				12
#define XAIEML_EVENTS_MEM_TILE_EDGE_DETECTION_EVENT_0			13
#define XAIEML_EVENTS_MEM_TILE_EDGE_DETECTION_EVENT_1			14
#define XAIEML_EVENTS_MEM_TILE_GROUP_WATCHPOINT				15
#define XAIEML_EVENTS_MEM_TILE_WATCHPOINT_0				16
#define XAIEML_EVENTS_MEM_TILE_WATCHPOINT_1				17
#define XAIEML_EVENTS_MEM_TILE_WATCHPOINT_2				18
#define XAIEML_EVENTS_MEM_TILE_WATCHPOINT_3				19
#define XAIEML_EVENTS_MEM_TILE_GROUP_DMA_ACTIVITY			20
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL0_START_TASK			21
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL1_START_TASK			22
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL0_START_TASK			23
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL1_START_TASK			24
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL0_FINISHED_BD			25
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL1_FINISHED_BD			26
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL0_FINISHED_BD			27
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL1_FINISHED_BD			28
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL0_FINISHED_TASK		29
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL1_FINISHED_TASK		30
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL0_FINISHED_TASK		31
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL1_FINISHED_TASK		32
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL0_STALLED_LOCK		33
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL1_STALLED_LOCK		34
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL0_STALLED_LOCK		35
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL1_STALLED_LOCK		36
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL0_STREAM_STARVATION		37
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL1_STREAM_STARVATION		38
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL0_STREAM_BACKPRESSURE		39
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL1_STREAM_BACKPRESSURE		40
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL0_MEMORY_BACKPRESSURE		41
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_SEL1_MEMORY_BACKPRESSURE		42
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL0_MEMORY_STARVATION		43
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_SEL1_MEMORY_STARVATION		44
#define XAIEML_EVENTS_MEM_TILE_GROUP_LOCK				45
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL0_ACQ_EQ				46
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL0_ACQ_GE				47
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL0_REL				48
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL0_EQUAL_TO_VALUE			49
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL1_ACQ_EQ				50
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL1_ACQ_GE				51
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL1_REL				52
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL1_EQUAL_TO_VALUE			53
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL2_ACQ_EQ				54
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL2_ACQ_GE				55
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL2_REL				56
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL2_EQUAL_TO_VALUE			57
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL3_ACQ_EQ				58
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL3_ACQ_GE				59
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL3_REL				60
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL3_EQUAL_TO_VALUE			61
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL4_ACQ_EQ				62
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL4_ACQ_GE				63
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL4_REL				64
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL4_EQUAL_TO_VALUE			65
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL5_ACQ_EQ				66
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL5_ACQ_GE				67
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL5_REL				68
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL5_EQUAL_TO_VALUE			69
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL6_ACQ_EQ				70
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL6_ACQ_GE				71
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL6_REL				72
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL6_EQUAL_TO_VALUE			73
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL7_ACQ_EQ				74
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL7_ACQ_GE				75
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL7_REL				76
#define XAIEML_EVENTS_MEM_TILE_LOCK_SEL7_EQUAL_TO_VALUE			77
#define XAIEML_EVENTS_MEM_TILE_GROUP_STREAM_SWITCH			78
#define XAIEML_EVENTS_MEM_TILE_PORT_IDLE_0				79
#define XAIEML_EVENTS_MEM_TILE_PORT_RUNNING_0				80
#define XAIEML_EVENTS_MEM_TILE_PORT_STALLED_0				81
#define XAIEML_EVENTS_MEM_TILE_PORT_TLAST_0				82
#define XAIEML_EVENTS_MEM_TILE_PORT_IDLE_1				83
#define XAIEML_EVENTS_MEM_TILE_PORT_RUNNING_1				84
#define XAIEML_EVENTS_MEM_TILE_PORT_STALLED_1				85
#define XAIEML_EVENTS_MEM_TILE_PORT_TLAST_1				86
#define XAIEML_EVENTS_MEM_TILE_PORT_IDLE_2				87
#define XAIEML_EVENTS_MEM_TILE_PORT_RUNNING_2				88
#define XAIEML_EVENTS_MEM_TILE_PORT_STALLED_2				89
#define XAIEML_EVENTS_MEM_TILE_PORT_TLAST_2				90
#define XAIEML_EVENTS_MEM_TILE_PORT_IDLE_3				91
#define XAIEML_EVENTS_MEM_TILE_PORT_RUNNING_3				92
#define XAIEML_EVENTS_MEM_TILE_PORT_STALLED_3				93
#define XAIEML_EVENTS_MEM_TILE_PORT_TLAST_3				94
#define XAIEML_EVENTS_MEM_TILE_PORT_IDLE_4				95
#define XAIEML_EVENTS_MEM_TILE_PORT_RUNNING_4				96
#define XAIEML_EVENTS_MEM_TILE_PORT_STALLED_4				97
#define XAIEML_EVENTS_MEM_TILE_PORT_TLAST_4				98
#define XAIEML_EVENTS_MEM_TILE_PORT_IDLE_5				99
#define XAIEML_EVENTS_MEM_TILE_PORT_RUNNING_5				100
#define XAIEML_EVENTS_MEM_TILE_PORT_STALLED_5				101
#define XAIEML_EVENTS_MEM_TILE_PORT_TLAST_5				102
#define XAIEML_EVENTS_MEM_TILE_PORT_IDLE_6				103
#define XAIEML_EVENTS_MEM_TILE_PORT_RUNNING_6				104
#define XAIEML_EVENTS_MEM_TILE_PORT_STALLED_6				105
#define XAIEML_EVENTS_MEM_TILE_PORT_TLAST_6				106
#define XAIEML_EVENTS_MEM_TILE_PORT_IDLE_7				107
#define XAIEML_EVENTS_MEM_TILE_PORT_RUNNING_7				108
#define XAIEML_EVENTS_MEM_TILE_PORT_STALLED_7				109
#define XAIEML_EVENTS_MEM_TILE_PORT_TLAST_7				110
#define XAIEML_EVENTS_MEM_TILE_GROUP_MEMORY_CONFLICT			111
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_0			112
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_1			113
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_2			114
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_3			115
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_4			116
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_5			117
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_6			118
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_7			119
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_8			120
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_9			121
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_10			122
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_11			123
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_12			124
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_13			125
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_14			126
#define XAIEML_EVENTS_MEM_TILE_CONFLICT_DM_BANK_15			127
#define XAIEML_EVENTS_MEM_TILE_GROUP_ERRORS				128
#define XAIEML_EVENTS_MEM_TILE_DM_ECC_ERROR_SCRUB_CORRECTED		129
#define XAIEML_EVENTS_MEM_TILE_DM_ECC_ERROR_SCRUB_2BIT			130
#define XAIEML_EVENTS_MEM_TILE_DM_ECC_ERROR_1BIT				131
#define XAIEML_EVENTS_MEM_TILE_DM_ECC_ERROR_2BIT				132
#define XAIEML_EVENTS_MEM_TILE_DMA_S2MM_ERROR				133
#define XAIEML_EVENTS_MEM_TILE_DMA_MM2S_ERROR				134
#define XAIEML_EVENTS_MEM_TILE_STREAM_SWITCH_PARITY_ERROR		135
#define XAIEML_EVENTS_MEM_TILE_STREAM_PKT_ERROR				136
#define XAIEML_EVENTS_MEM_TILE_CONTROL_PKT_ERROR				137
#define XAIEML_EVENTS_MEM_TILE_AXI_MM_SLAVE_ERROR			138
#define XAIEML_EVENTS_MEM_TILE_LOCK_ERROR				139
#define XAIEML_EVENTS_MEM_TILE_DMA_TASK_TOKEN_STALL			140
#define XAIEML_EVENTS_MEM_TILE_GROUP_BROADCAST				141
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_0				142
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_1				143
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_2				144
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_3				145
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_4				146
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_5				147
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_6				148
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_7				149
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_8				150
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_9				151
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_10				152
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_11				153
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_12				154
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_13				155
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_14				156
#define XAIEML_EVENTS_MEM_TILE_BROADCAST_15				157
#define XAIEML_EVENTS_MEM_TILE_GROUP_USER_EVENT				158
#define XAIEML_EVENTS_MEM_TILE_USER_EVENT_0				159
#define XAIEML_EVENTS_MEM_TILE_USER_EVENT_1				160
/** @} */
